@@ -1,10 +1,12 @@
 package PMLTQ::Command;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Command::VERSION = '1.4.0';
+$PMLTQ::Command::VERSION = '1.5.0';
 # ABSTRACT: Command base class
 
 use PMLTQ::Base -base;
 
+use utf8;
+
 use DBI;
 use File::Slurp;
 use Pod::Usage 'pod2usage';
@@ -14,6 +16,7 @@ use LWP::UserAgent;
 use HTTP::Cookies;
 use URI::WithBase;
 use URI::Encode qw(uri_encode);
+use Encode;
 
 has config => sub { die 'Command has no configuration'; };
 
@@ -50,7 +53,6 @@ sub help {
 
 sub _db_connect {
   my ( $database, $host, $port, $user, $password ) = @_;
-
   my $dbh = DBI->connect( 'DBI:Pg:dbname=' . $database . ';host=' . $host . ';port=' . $port,
     $user, $password, { RaiseError => 1, PrintError => 1 } )
     or die "Unable to connect to database!\n$DBI::errstr\n";
@@ -96,6 +98,7 @@ sub run_sql_from_file {
       open my $fh, '<', "$dump_file" or die "Can't open $dump_file: $!";
       while ( my $data = <$fh> ) {    # Do not load whole file, but process it line by line
         next unless $data;
+        $data= Encode::decode("UTF-8", $data, Encode::FB_CROAK);
         $dbh->pg_putcopydata("$data");
       }
       $dbh->pg_putcopyend();
@@ -338,7 +341,7 @@ sub user2admin_format { # converts getted treebank json to treebank configuratio
   return {
     id => $treebank->{name},
     tags => [map  {$_->{name}} @{$treebank->{tags}}],
-    language => $treebank->{languages}->[0]->{code}, 
+    language => $treebank->{languages}->[0]->{code},
     map {$_ => $treebank->{$_}} qw/title isFree isAllLogged isFeatured isPublic homepage description documentation dataSources manuals/
   }
 }
@@ -374,7 +377,7 @@ PMLTQ::Command - Command base class
 
 =head1 VERSION
 
-version 1.4.0
+version 1.5.0
 
 =head1 AUTHORS
 
